@@ -75,11 +75,11 @@ class WebServer(objects.Thread):
 			"port":port,
 			"cache":default,
 		})
-	def set(self, group=None, id=None, value=None):
+	def set(self, group=None, id=None, data=None):
 		encoded = urllib.parse.urlencode({
-			"key":key,
+			"group":group,
 			"id":id,
-			"value":value,
+			"data":data,
 			"token":self.token(),
 		})
 		try:
@@ -87,13 +87,14 @@ class WebServer(objects.Thread):
 		except Exception as e:
 			return r3sponse.error_response(f"Failed to connect with {self.host}:{self.port}, error: {e}")
 		try:
-			response = response.json()
+			response = self.__serialize__(response.json())
 		except:
-			return r3sponse.error_response(f"Failed to serialize output: {response}, status code {response.status_code}")
+			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
 		return r3sponse.ResponseObject(response)
 	def get(self, group=None, id=None):
 		encoded = urllib.parse.urlencode({
-			"key":key,
+			"group":group,
+			"id":id,
 			"token":self.token(),
 		})
 		try:
@@ -101,9 +102,9 @@ class WebServer(objects.Thread):
 		except Exception as e:
 			return r3sponse.error_response(f"Failed to connect with {self.host}:{self.port}, error: {e}")
 		try:
-			response = response.json()
+			response = self.__serialize__(response.json())
 		except:
-			return r3sponse.error_response(f"Failed to serialize output: {response}, status code {response.status_code}")
+			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
 		return r3sponse.ResponseObject(response)
 	def app(self):
 		app = flask.Flask(__name__)
@@ -111,44 +112,48 @@ class WebServer(objects.Thread):
 		cli.show_server_banner = lambda *x: None
 		@app.route('/get')
 		def get():
-			token = request.args.get('token')
-			if token != self.token():
-				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
-			key = request.args.get('key')
-			id = request.args.get('id')
+			#token = flask.request.args.get('token')
+			#if token != self.token():
+			#	return r3sponse.error_response(f"Provided an invalid token {token}.").json()
+			group = flask.request.args.get('group')
+			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
 			try:
 				if id == None:
-					value = self.cache[key]
+					tag = f"{group}"
+					value = self.cache[group]
 				else:
-					value = self.cache[key][id]
+					tag = f"{group}:{id}"
+					value = self.cache[group][id]
 			except KeyError:
-				return r3sponse.error_response(f"There is no value cached for key {key}.").json()
-			return r3sponse.success_response(f"Successfully retrieved {key}.", {
-				"key":key,
-				"value":value,
+				return r3sponse.error_response(f"There is no data cached for {tag}.").json()
+			return r3sponse.success_response(f"Successfully retrieved {tag}.", {
+				"group":group,
+				"data":value,
 			}).json()
 		@app.route('/set')
-		def set__(self):
-			token = request.args.get('token')
-			if token != self.token():
-				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
-			key = request.args.get('key')
-			id = request.args.get('id')
+		def set__():
+			#token = flask.request.args.get('token')
+			#if token != self.token():
+			#	return r3sponse.error_response(f"Provided an invalid token {token}.").json()
+			group = flask.request.args.get('group')
+			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
-			value = request.args.get('value')
+			value = flask.request.args.get('value')
 			if id == None:
-				self.cache[key] = value
+				tag = f"{group}"
+				self.cache[group] = value
 			else:
-				try: self.cache[key]
-				except KeyError: self.cache[key] = {}
-				self.cache[key][id] = value
-			return r3sponse.success_response(f"Successfully cached {key}.").json()
+				tag = f"{group}:{id}"
+				try: self.cache[group]
+				except KeyError: self.cache[group] = {}
+				self.cache[group][id] = value
+			return r3sponse.success_response(f"Successfully cached {tag}.").json()
 		@app.route('/active')
-		def active__(self):
-			token = request.args.get('token')
-			if token != self.token():
-				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
+		def active__():
+			#token = flask.request.args.get('token')
+			#if token != self.token():
+			#	return r3sponse.error_response(f"Provided an invalid token {token}.").json()
 			return r3sponse.success_response(f"Active.").json()
 		#def run__(self, app, host, port):
 		#	app.run(host=host, port=port)
@@ -173,6 +178,18 @@ class WebServer(objects.Thread):
 		self.__cache__.set(group=self.id, id="token", data=Formats.String("").generate(length=64, digits=True, capitalize=True))
 		self.app()
 		self.__cache__.set(group=self.id, id="daemon", data="*stopped*")
+	def __serialize__(self, dict):
+		for key in list(dict.keys()):
+			value = dict[key]
+			if value in ["False", "false"]: dict[key] = False
+			elif value in ["True", "true"]: dict[key] = True
+			elif value in ["None", "none", "null", "nan"]: dict[key] = None
+			else:
+				try: 
+					int(value)
+					dict[key] = int(value)
+				except: a=1
+		return dict
 	#def stop(self):
 	#	self.process.terminate()
 	#	self.process.join()
